@@ -77,13 +77,13 @@ class IOSSpeechDriver(BaseDriver):
 					return v.id
 		raise Exception(f'{lang} is not supported language')
 			
-	def _toVoice(voice):
-		id = voice.identifier
-		name = voice.name
+	def _toVoice(self, voice):
+		print('_toVoice(): voice:', dir(voice))
+		id = voice.valueForKey_('identifier')
 		v = Voice(id)
-		v.name = voice.name
-		v.gender = voice.gender
-		v.languages = voice.language
+		v.name = voice.valueForKey_('name')
+		v.gender = voice.valueForKey_('gender')
+		v.languages = [voice.valueForKey_('language')]
 		return v
 
 	def get_voices(self):
@@ -130,17 +130,6 @@ class IOSSpeechDriver(BaseDriver):
 			return x
 		return x.decode('utf-8')
 
-	def _toVoice(self, attr):
-		try:
-			lang = self.nss2s(attr.valueForKey_('VoiceLocaleIdentifier'))
-		except KeyError:
-			lang = self.nss2s(attr.valueForKey_('VoiceLanguage'))
-		return Voice(self.nss2s(attr.valueForKey_('VoiceIdentifier')),
-						self.nss2s(attr.valueForKey_('VoiceName')),
-					 [lang], attr.valueForKey_('VoiceGender'),
-					 attr.valueForKey_('VoiceAge').intValue())
-
-
 	def set_utterances_by_sentence(self, utterance, sentence):
 		if sentence.dialog:
 			utterance.pitchModifier = 1.25
